% Created by Alessio Del Bue and Lourdes Agapito
% Last Modified: 04/01/2005
%
% Function: M = fact_plugLR(L,R)
%
% Simply plug together the configuration weights and camera matrices to
% obtain the motion component M. The scalar F represents the number of
% frames and K is the number of bases of the deformable model.
%
% Input:
% 
% L: K x F configuration weights matrix 
% R: 2F x 3 matrix which stores orthographic camera matrices at each frame
% 
% Output:
%
% M: Motion component of size 2F x 3K

function M = fact_plugLR(L,R)

% Copyright (C) 2009 Alessio Del Bue and Lourdes Agapito.
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.

f=size(R,1)/2;

for i=1:f
    M(2*i-1:2*i,:) = kron(L(:,i)',R(2*i-1:2*i,:)); 
end