% Created by Alessio Del Bue and Lourdes Agapito
% Last Modified: 03/01/2005
%
% Function: Wr = fact_reproject(L,R,S,T,scale)
% reproject the factorization components to reconstruct the measurement
% matrix Wr.
%
% Input:
%
% S: shape matrix of dim 3*K by P. Contains the K basis shapes. 
% M: motion matrix, it encodes configuration weights and rotation parameters. 
% R: rotation matrix, size 2F by 3. 
% L: configuration matrix of dim K by F. 
% T: translation vector, results from the centroid calculation. Size 2*F by 1
% scale: scale factor used to normalize the measurement matrix W
%
% Output
%
% Wr: measurement matrix of size 2F by P where F is # of frames and P # of
% feature points

function Wr = fact_reproject(L,R,S,T,scale)

% Copyright (C) 2009 Alessio Del Bue and Lourdes Agapito.
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.

Mr = fact_plugLR(L,R);
Wr = Mr*S*scale;
p = size(S,2);
Tr = kron(ones(1,p),T);
Wr = Wr+Tr;
